Image Input and Output (imgcodecs module) {#tutorial_table_of_content_imgcodecs}
=========================================

This section contains tutorials about how to read/save your image files.

-   @subpage tutorial_raster_io_gdal

    *Languages:* C++

    *Compatibility:* \> OpenCV 2.0

    *Author:* Marvin Smith

    Read common GIS Raster and DEM files to display and manipulate geographic data.
